@@ -151,9 +151,12 @@ let Tabs = {
         break
       }
     }
+
+    // move nonfield errors outside of tabs
+    $('.errornote').after($('.errorlist.nonfield'))
   },
   checkHash: function () {
-    if (location.hash) {
+    if (location.hash && this.nav.find('a[data-bs-target="' + location.hash + '"]').length) {
       const tab = new bootstrap.Tab(this.nav.find('a[data-bs-target="' + location.hash + '"]')[0])
       tab.show()
     }
